Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7239)

Unified Diff: chrome/utility/importer/firefox_importer.h

Issue 2296633002: Fix Firefox bookmarks import. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: build fix Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/BUILD.gn ('k') | chrome/utility/importer/firefox_importer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/utility/importer/firefox_importer.h
diff --git a/chrome/utility/importer/firefox_importer.h b/chrome/utility/importer/firefox_importer.h
index a15df112f21d4bdb7e63eaf29e0ca6ef2fbf0c98..c3f648f165483a2d618438c1a4ef1b35ad6fb10c 100644
--- a/chrome/utility/importer/firefox_importer.h
+++ b/chrome/utility/importer/firefox_importer.h
@@ -16,6 +16,7 @@
#include "base/compiler_specific.h"
#include "base/files/file_path.h"
+#include "base/gtest_prod_util.h"
#include "base/macros.h"
#include "build/build_config.h"
#include "chrome/utility/importer/importer.h"
@@ -44,6 +45,7 @@ class FirefoxImporter : public Importer {
~FirefoxImporter() override;
+ FRIEND_TEST_ALL_PREFIXES(FirefoxImporterTest, ImportBookmarksV25);
void ImportBookmarks();
void ImportPasswords();
void ImportHistory();
@@ -60,9 +62,9 @@ class FirefoxImporter : public Importer {
struct BookmarkItem;
using BookmarkList = std::vector<std::unique_ptr<BookmarkItem>>;
- // Gets the specific IDs of bookmark root node from |db|.
- void LoadRootNodeID(sql::Connection* db, int* toolbar_folder_id,
- int* menu_folder_id, int* unsorted_folder_id);
+ // Gets the specific ID of bookmark node with given GUID from |db|.
+ // Returns -1 if not found.
+ int LoadNodeIDByGUID(sql::Connection* db, const std::string& GUID);
// Loads all livemark IDs from database |db|.
void LoadLivemarkIDs(sql::Connection* db, std::set<int>* livemark);
« no previous file with comments | « chrome/test/BUILD.gn ('k') | chrome/utility/importer/firefox_importer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698